/**
 * functions.js
 *
 * Custom javascript trigger.
 *
 */
( function( $ ) {
	"use strict";

	var is_webkit = navigator.userAgent.toLowerCase().indexOf( 'webkit' ) > -1,
	    is_opera  = navigator.userAgent.toLowerCase().indexOf( 'opera' )  > -1,
	    is_ie     = navigator.userAgent.toLowerCase().indexOf( 'msie' )   > -1;

	if ( ( is_webkit || is_opera || is_ie ) && document.getElementById && window.addEventListener ) {
		window.addEventListener( 'hashchange', function() {
			var id = location.hash.substring( 1 ),
				element;

			if ( ! ( /^[A-z0-9_-]+$/.test( id ) ) ) {
				return;
			}

			element = document.getElementById( id );

			if ( element ) {
				if ( ! ( /^(?:a|select|input|button|textarea)$/i.test( element.tagName ) ) ) {
					element.tabIndex = -1;
				}

				element.focus();
			}
		}, false );
	}

	// Fixed footer
	function fixedFooter() {
		var fh = $('.site-footer').height() + 100;
		var wh = $( window ).height();
		var dh = $( document ).height() - wh - fh;

		$( window ).scroll(function () {
			if ( $(window).scrollTop() >= dh ) {
				$( 'body' ).css( 'padding-bottom', fh + 'px' );
				$( '.site-footer' ).addClass( 'fixed' );
			} else {
				$( 'body' ).css('padding-bottom', '' );
				$( '.site-footer' ).removeClass( 'fixed' );
			}
		});
	}

	// Social share
	function socialShare() {
		var social = $( '.social-share .social' ),
			action = $( '.social-share .action' );

		social.hide();

		action.on( 'click', function() {
			social.toggle( 'slow' );
		});
	}

	// Search box
	function searchBox() {
		$( '.site-search i' ).on( 'click', function() {
			$( '.site-search form' ).addClass( 'overlay' );
			$( '.site-search input' ).focus();
		});
		$( '.site-search' ).on( 'click', '.close', function() {
			$('.overlay').removeClass('overlay');
		});
	}

	// Mobile Menu
	function initMobileMenu() {
		$('#primary-menu .menu-item-has-children').prepend('<span class="sub-trigger"></span>');

		$( '.mobile-trigger' ).click( function() {
			$( '.wrapper' ).toggleClass( 'is-visible' );
			$( this ).toggleClass( 'is-visible' );
		});
		$( '.sub-trigger' ).click( function() {
			$( this ).toggleClass( 'is-open' );
			$( this ).siblings( '.sub-menu' ).toggle( 300 );
		});
	}

	// Init light box
	function initLightBox() {
		$( '.gallery-group a' ).nivoLightbox();
	}

	// Blog format gallery
	function formatGallery() {
		$( '.moon-gallery' ).owlCarousel({
			singleItem: true,
			autoHeight: true
		});
	}

	// Tabbed content
	function initTabs() {
		$( 'ul.tabs li' ).click( function() {
			var tab_id = $( this ).attr( 'data-tab' );

			$( 'ul.tabs li' ).removeClass( 'active' );
			$( '.tab-pane' ).removeClass( 'active' );

			$( this ).addClass( 'active' );
			$("#" + tab_id ).addClass( 'active' );
		})
	}

	/**
	 * Document ready
	 * 
	 * @version 1.0.0
	 */
	$( document ).ready( function() {
		fixedFooter();
		socialShare();
		searchBox();
		initMobileMenu();
		initLightBox();
		formatGallery();
		initTabs();
	});
} )( jQuery );