<?php
/**
 * Moon Theme Customizer.
 *
 * @package Moon
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function nq_moon_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	// Logo
	$wp_customize->add_setting( 'logo' , array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wp_customize->add_control(
	   new WP_Customize_Image_Control(
		   $wp_customize,
		   'logo',
		   array(
			   'label'    => __( 'Upload a logo', 'moon' ),
			   'section'  => 'title_tagline',
			   'settings' => 'logo',
		   )
	   )
   );

	// Blog layout
	$wp_customize->add_section( 'blog_layout' , array(
		'title'      => __( 'Blog Layout', 'moon' ),
		'priority'   => 30,
	) );
	$wp_customize->add_setting( 'blog_layout', array(
		'default'           => '',
		'sanitize_callback' => NULL,
	) );
	$wp_customize->add_control( 'blog_layout', array(
		'label'   => __( 'Choose Blog Layout', 'moon' ),
		'type'    => 'select',
		'section' => 'blog_layout',
		'choices' => array(
			''  => __( 'Left Sidebar', 'nitro' ),
			'no-sidebar'    => __( 'No Sidebar', 'nitro' ),
			'right-sidebar' => __( 'Right Sidebar', 'nitro' ),
		)
	) );

	// Body color
	$wp_customize->add_setting( 'body_color' , array(
		'default'           => '#404040',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'body_color', 
		array(
			'label'    => __( 'Body Text Color', 'moon' ),
			'section'  => 'colors',
			'settings' => 'body_color',
		) ) 
	);

	// Body link color
	$wp_customize->add_setting( 'link_color' , array(
		'default'           => '#868686',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'link_color', 
		array(
			'label'    => __( 'Link Color', 'moon' ),
			'section'  => 'colors',
			'settings' => 'link_color',
		) ) 
	);
	$wp_customize->add_setting( 'link_hover_color' , array(
		'default'           => '#000000',
		'sanitize_callback' => 'sanitize_hex_color',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Color_Control( 
		$wp_customize, 
		'link_hover_color', 
		array(
			'label'    => __( 'Link Hover Color', 'moon' ),
			'section'  => 'colors',
			'settings' => 'link_hover_color',
		) ) 
	);

	// Footer
	$wp_customize->add_setting( 'footer_content' , array(
		'default'           => __( '(c) 2016 Moon - All Rights Reserved.', 'moon' ),
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control( 
		new WP_Customize_Control( 
		$wp_customize, 
		'footer_content', 
		array(
			'label'    => __( 'Site Copyright', 'moon' ),
			'section'  => 'title_tagline',
			'settings' => 'footer_content',
			'type'     => 'textarea',
		) ) 
	);
}
add_action( 'customize_register', 'nq_moon_customize_register' );

/**
 * Custom style.
 *
 * @since Moon 1.0.0
 *
 */
if ( ! function_exists( 'nq_moon_custom_css' ) ) {
	function nq_moon_custom_css( $css = array() ) {
		$bg_color         = get_theme_mod( 'background_color' );
		$body_color       = get_theme_mod( 'body_color' );
		$link_color       = get_theme_mod( 'link_color' );
		$link_hover_color = get_theme_mod( 'link_hover_color' );

		// Header Image
		$header_image = get_header_image();
		
		$css[] = 'body {';
			$css[] = 'color: ' . esc_attr( $body_color ) . ';';
		$css[] = '}';

		$css[] = 'a {';
			$css[] = 'color: ' . esc_attr( $link_color ) . ';';
		$css[] = '}';

		$css[] = 'a:hover {';
			$css[] = 'color: ' . esc_attr( $link_hover_color ) . ';';
		$css[] = '}';

		$css[] = '.site-content {';
			$css[] = 'background-color: #' . esc_attr( $bg_color ) . ';';
		$css[] = '}';

		if ( ! empty( $header_image ) ) {
			$css[] = '.site-header {';
				$css[] = '
					background-image: url( header_image() );
					background-repeat: no-repeat;
					background-position: 50% 50%;
					background-size: cover;
				';
			$css[] = '}';
		}

		return implode( '', $css );
	}
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function nq_moon_customize_preview() {
	wp_enqueue_script( 'moon-customizer-preview', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '', true );
}
add_action( 'customize_preview_init', 'nq_moon_customize_preview' );
