<?php
/**
 * Flickr widget.
 *
 * @package Moon
 * @since   1.0.0
 */

class NQ_Moon_Widget_Flickr extends WP_Widget {

	function __construct() {
		$widget_ops  = array(
			'description' => __( 'Show off your favorite Flickr photos', 'moon' )
		);
		$control_ops = array(
			'width'  => 'auto',
			'height' => 'auto'
		);
		parent::__construct( 'moon_flickr', __( 'Moon - Flickr', 'moon' ), $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );
		$title   = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$id      = empty($instance['id']) ? '' : $instance['id'];
		$limit   = empty( $instance['limit'] ) ? 4 : ( int ) $instance['limit'];
		$columns = empty( $instance['columns'] ) ? 2 : ( int ) $instance['columns'];

		echo $before_widget;
		
		if ( ! empty( $title ) ) {
			echo $before_title . $title . $after_title;
		}
		$output = '<div class="flickr clear cols-' . esc_attr( $columns ) . '">';
			$output .= '<scr' . 'ipt type="text/javascript" src="http://www.flickr.com/badge_code_v2.gne?count=' . $limit . '&amp;display=latest&amp;size=s&amp;layout=x&amp;source=user&amp;user=' . $id . '"></scr' . 'ipt>';
		$output .= '</div>';

		echo $output . $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = array();
		if ( ! empty( $new_instance['title'] ) ) {
			$instance['title'] = sanitize_text_field( $new_instance['title'] );
		}
		if ( ! empty( $new_instance['id'] ) ) {
			$instance['id'] = sanitize_text_field( $new_instance['id'] );
		}
		if ( ! empty( $new_instance['limit'] ) ) {
			$instance['limit'] = ( int ) $new_instance['limit'];
		}
		if ( ! empty( $new_instance['columns'] ) ) {
			$instance['columns'] = ( int ) $new_instance['columns'];
		}
		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( ( array ) $instance, array( 'title' => '', 'id' => '', 'limit' => 4, 'columns' => 2 ) );
		$title    = strip_tags( $instance['title'] );
		$id       = isset( $instance['id'] ) ? $instance['id'] : array();
		$limit    = ( int ) $instance['limit'];
		$columns  = ( int ) $instance['columns'];

		$url = 'http://idgettr.com';
	?>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'id' ) ); ?>"><?php printf( wp_kses( __( 'Flickr user ID (<a target="_blank" href="%1$s">Lookup your User ID</a>)', 'moon' ), array( 'a' => array( 'href' => array(), 'target' => array() ) ) ), esc_url( $url ) ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'id' ) ); ?>" type="text" value="<?php echo esc_attr( $id ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'limit' ) ); ?>"><?php _e( 'Number of Photos:', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'limit' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'limit' ) ); ?>" type="number" min="1" value="<?php echo esc_attr( $limit ); ?>" />
		</p>

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>"><?php _e( 'Columns (1-5):', 'moon' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'columns' ) ); ?>" type="number" min="1" max="5" step="1" value="<?php echo esc_attr( $columns ); ?>" />
		</p>

	<?php
	}
}